import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import * as reset from '../reset';
import Tick from '../Svg/Tick';

const Checkbox = props => React.createElement(
  CheckboxComponent,
  _extends({}, props, {
    onClick: () => {
      if (!props.disabled) {
        props.onClick();
      }
    }
  }),
  React.createElement(
    BoxContainer,
    _extends({}, props, { onClick: () => {} }),
    props.checked && React.createElement(Tick, {
      style: { padding: '5px' },
      color: (props.error || props.disabled) && 'black',
      size: '30px'
    })
  ),
  props.label
);

const BoxContainer = reset.div`
  width: 24px;
  height: 24px;
  margin-right: 12px;
  border-width: 1px;
  border-style: solid;
  border-radius: 4px;
  border-color: ${p => {
  if (p.disabled) {
    return p.theme.checkbox.unchecked.disabled.border.color;
  }
  if (p.error) {
    return p.theme.checkbox.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.default.border.color;
  }
  return p.theme.checkbox.unchecked.default.border.color;
}};
  background-color: ${p => {
  if (p.disabled) {
    return p.theme.checkbox.unchecked.disabled.background.color;
  }
  if (p.error) {
    return p.theme.checkbox.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.default.background.color;
  }
  return p.theme.checkbox.unchecked.default.background.color;
}};
`;

export const CheckboxComponent = reset.div`
  display: flex;
  user-select: none;
  font-family: ${p => p.theme.text.body.fontFamily};
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
  color: ${p => p.theme.checkbox.unchecked.default.text.color};
  margin: 18px 0;
  cursor: default;
  &:hover {
    ${BoxContainer} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.checkbox.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.hover.border.color;
  }
  return p.theme.checkbox.unchecked.hover.border.color;
}};
      background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.checkbox.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.hover.background.color;
  }
  return p.theme.checkbox.unchecked.hover.background.color;
}};
    }
  }
  &:active {
    ${BoxContainer} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.checkbox.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.focus.border.color;
  }
  return p.theme.checkbox.unchecked.focus.border.color;
}}
      background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.checkbox.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checkbox.checked.focus.background.color;
  }
  return p.theme.checkbox.unchecked.focus.background.color;
}}
    }
  }
`;

Checkbox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Checks the box
   */
  checked: PropTypes.bool.isRequired,
  /**
   * Disable checkbox
   */
  disabled: PropTypes.bool,
  /**
   * Error state
   */
  error: PropTypes.bool,
  /**
   * Sets the label for the checkbox
   */
  label: PropTypes.string.isRequired,
  /**
   * onClick handler
   */
  onClick: PropTypes.func
} : {};

Checkbox.defaultProps = {
  label: '',
  checked: false
};

export default Checkbox;