import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';

const regularStyle = css`
  font-size: ${p => p.theme.text.body.fontSize}px;
  padding-top: ${p => p.theme.text.body.paddingTop}px;
  padding-bottom: 18px;
`;

const smallStyle = css`
  font-size: ${p => p.theme.text.caption.fontSize}px;
  padding-top: 7px;
  padding-bottom: 11px;
`;

export const LinkComponent = reset.a`
  font-family: ${p => p.theme.text.body.fontFamily};
  line-height: ${p => p.theme.text.body.lineHeight}px;
  display: ${p => p.wholeLine && 'block'};
  color: ${p => p.theme.text.link.color};
  ${props => props.align && `text-align: ${props.align};`};
  ${props => props.noWrap && noWrap};
  ${props => props.variation === 'small' ? smallStyle : regularStyle}
`;

const Link = props => React.createElement(LinkComponent, props);

Link.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the text-align on the component.
   */
  align: PropTypes.oneOf(['inherit', 'left', 'center', 'right', 'justify']),
  /**
   * If `true`, the text will not wrap, but instead will truncate with an ellipsis.
   */
  noWrap: PropTypes.bool,
  /**
   * Regular or small link.
   */
  variation: PropTypes.oneOf(['regular', 'small']),
  /**
   * Whole line
   */
  wholeLine: PropTypes.bool
} : {};

Link.defaultProps = {
  variation: 'regular',
  noWrap: false,
  align: 'inherit',
  wholeLine: false
};

export default Link;